# Project Goals

Goals of this package:

- [ ] Data/Visual Lineage Tool
    * [x] Low-level SSAS interface for updating PBIX Data Models
    * [x] Low-level interface for updating Static PBIX elements
    * [x] Intra-SSAS lineage
    * [x] Intra-layout lineage
    * [x] Layout-SSAS lineage
- [x] AST parser for DAX Queries
- [x] AST parser for M Queries
- [ ] Automatic Data Refresh
    * [x] with Desktop PBIX SSAS
    * [ ] with self-created SSAS
- [x] Automated Data Extraction
    * [x] At the Column Level
    * [x] At the Table Level
    * [x] At the Measure Level
    * [x] At the Visual Level
- [x] Automated Performance Testing
    * [x] At the Column Level
    * [x] At the Table Level
    * [x] At the Measure Level
    * [x] At the Visual Level
- [ ] Linting Tools
    * [ ] Layout stylistic Linting
    * [x] DAX Formatter
    * [x] DAX Linting
    * [ ] M Query Linting
- [ ] Remote PowerBI Manipulation
    * [ ] Incorporating REST API lib
    * [ ] Include non-REST endpoints
    * [ ] Report Deployment
    * [ ] Report Download
    * [ ] Viewship, etc. statistics
- [ ] Built-In Data Export Options
    * [ ] To Postgres
    * [ ] To SQLite
    * [ ] To CSVs
